summaryrefslogtreecommitdiffstats
path: root/korganizer/actionmanager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/actionmanager.cpp')
-rw-r--r--korganizer/actionmanager.cpp42
1 files changed, 21 insertions, 21 deletions
diff --git a/korganizer/actionmanager.cpp b/korganizer/actionmanager.cpp
index 741a04f8..68fd6b4d 100644
--- a/korganizer/actionmanager.cpp
+++ b/korganizer/actionmanager.cpp
@@ -77,7 +77,7 @@
#include <tqtimer.h>
#include <tqlabel.h>
// FIXME: Several places in the file don't use KConfigXT yet!
KOWindowList *ActionManager::mWindowList = 0;
ActionManager::ActionManager( KXMLGUIClient *client, CalendarView *widget,
@@ -573,7 +573,7 @@ void ActionManager::initActions()
mEventViewerShowAction = new KToggleAction ( i18n("Show Item Viewer"), 0,
TQT_TQOBJECT(this), TQT_SLOT( toggleEventViewer() ),
mACollection, "show_eventviewer" );
- KConfig *config = KOGlobals::self()->config();
+ TDEConfig *config = KOGlobals::self()->config();
config->setGroup( "Settings" );
mDateNavigatorShowAction->setChecked(
config->readBoolEntry( "DateNavigatorVisible", true ) );
@@ -655,10 +655,10 @@ void ActionManager::initActions()
void ActionManager::readSettings()
{
// read settings from the KConfig, supplying reasonable
// defaults where none are to be found
- KConfig *config = KOGlobals::self()->config();
+ TDEConfig *config = KOGlobals::self()->config();
if ( mRecent ) mRecent->loadEntries( config );
mCalendarView->readSettings();
}
@@ -667,7 +667,7 @@ void ActionManager::writeSettings()
{
kdDebug(5850) << "ActionManager::writeSettings" << endl;
- KConfig *config = KOGlobals::self()->config();
+ TDEConfig *config = KOGlobals::self()->config();
mCalendarView->writeSettings();
config->setGroup( "Settings" );
@@ -847,7 +847,7 @@ void ActionManager::file_close()
if ( !saveModifiedURL() ) return;
mCalendarView->closeCalendar();
- KIO::NetAccess::removeTempFile( mFile );
+ TDEIO::NetAccess::removeTempFile( mFile );
mURL="";
mFile="";
@@ -883,19 +883,19 @@ bool ActionManager::openURL( const KURL &url,bool merge )
setTitle();
} else {
TQString tmpFile;
- if( KIO::NetAccess::download( url, tmpFile, view() ) ) {
+ if( TDEIO::NetAccess::download( url, tmpFile, view() ) ) {
kdDebug(5850) << "--- Downloaded to " << tmpFile << endl;
bool success = mCalendarView->openCalendar( tmpFile, merge );
if ( merge ) {
- KIO::NetAccess::removeTempFile( tmpFile );
+ TDEIO::NetAccess::removeTempFile( tmpFile );
if ( success )
showStatusMessageOpen( url, merge );
} else {
if ( success ) {
- KIO::NetAccess::removeTempFile( mFile );
+ TDEIO::NetAccess::removeTempFile( mFile );
mURL = url;
mFile = tmpFile;
- KConfig *config = KOGlobals::self()->config();
+ TDEConfig *config = KOGlobals::self()->config();
config->setGroup( "General" );
setTitle();
kdDebug(5850) << "-- Add recent URL: " << url.prettyURL() << endl;
@@ -1016,7 +1016,7 @@ bool ActionManager::saveURL()
}
if ( !mURL.isLocalFile() ) {
- if ( !KIO::NetAccess::upload( mFile, mURL, view() ) ) {
+ if ( !TDEIO::NetAccess::upload( mFile, mURL, view() ) ) {
TQString msg = i18n("Cannot upload calendar to '%1'")
.arg( mURL.prettyURL() );
KMessageBox::error( dialogParent() ,msg );
@@ -1093,7 +1093,7 @@ void ActionManager::exportHTML( HTMLExportSettings *settings )
TQString tfile = tf.name();
tf.close();
mExport.save( tfile );
- if ( !KIO::NetAccess::upload( tfile, dest, view() ) ) {
+ if ( !TDEIO::NetAccess::upload( tfile, dest, view() ) ) {
KNotifyClient::event ( view()->winId(),
i18n("Could not upload file.") );
}
@@ -1130,8 +1130,8 @@ bool ActionManager::saveAsURL( const KURL &url )
if ( success ) {
delete mTempFile;
mTempFile = tempFile;
- KIO::NetAccess::removeTempFile( fileOrig );
- KConfig *config = KOGlobals::self()->config();
+ TDEIO::NetAccess::removeTempFile( fileOrig );
+ TDEConfig *config = KOGlobals::self()->config();
config->setGroup( "General" );
setTitle();
if ( mRecent ) mRecent->addURL( mURL );
@@ -1208,7 +1208,7 @@ KURL ActionManager::getSaveURL()
return url;
}
-void ActionManager::saveProperties( KConfig *config )
+void ActionManager::saveProperties( TDEConfig *config )
{
kdDebug(5850) << "ActionManager::saveProperties" << endl;
@@ -1218,7 +1218,7 @@ void ActionManager::saveProperties( KConfig *config )
}
}
-void ActionManager::readProperties( KConfig *config )
+void ActionManager::readProperties( TDEConfig *config )
{
kdDebug(5850) << "ActionManager::readProperties" << endl;
@@ -2055,9 +2055,9 @@ void ActionManager::slotAutoArchive()
void ActionManager::loadProfile( const TQString & path )
{
KOPrefs::instance()->writeConfig();
- KConfig* const cfg = KOPrefs::instance()->config();
+ TDEConfig* const cfg = KOPrefs::instance()->config();
- const KConfig profile( path+"/korganizerrc", /*read-only=*/false, /*useglobals=*/false );
+ const TDEConfig profile( path+"/korganizerrc", /*read-only=*/false, /*useglobals=*/false );
const TQStringList groups = profile.groupList();
for ( TQStringList::ConstIterator it = groups.begin(), end = groups.end(); it != end; ++it )
{
@@ -2075,7 +2075,7 @@ void ActionManager::loadProfile( const TQString & path )
}
namespace {
- void copyConfigEntry( KConfig* source, KConfig* dest, const TQString& group, const TQString& key, const TQString& defaultValue=TQString() )
+ void copyConfigEntry( TDEConfig* source, TDEConfig* dest, const TQString& group, const TQString& key, const TQString& defaultValue=TQString() )
{
source->setGroup( group );
dest->setGroup( group );
@@ -2086,9 +2086,9 @@ namespace {
void ActionManager::saveToProfile( const TQString & path ) const
{
KOPrefs::instance()->writeConfig();
- KConfig* const cfg = KOPrefs::instance()->config();
+ TDEConfig* const cfg = KOPrefs::instance()->config();
- KConfig profile( path+"/korganizerrc", /*read-only=*/false, /*useglobals=*/false );
+ TDEConfig profile( path+"/korganizerrc", /*read-only=*/false, /*useglobals=*/false );
::copyConfigEntry( cfg, &profile, "Views", "Agenda View Calendar Display" );
}
@@ -77,7 +77,7 @@
#include <tqtimer.h>
#include <tqlabel.h>
-// FIXME: Several places in the file don't use KConfigXT yet!
+// FIXME: Several places in the file don't use TDEConfigXT yet!
KOWindowList *ActionManager::mWindowList = 0;
ActionManager::ActionManager( KXMLGUIClient *client, CalendarView *widget,
@@ -655,10 +655,10 @@ void ActionManager::initActions()
void ActionManager::readSettings()
{
- // read settings from the KConfig, supplying reasonable
+ // read settings from the TDEConfig, supplying reasonable
// defaults where none are to be found